Validators class
Validation utilities for Dorar API inputs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validateBookId(
String? id) → String - Validates book ID format.
-
validateHadithId(
String? id) → String - Validates hadith ID format.
-
validateMohdithId(
String? id) → String - Validates mohdith ID format.
-
validatePage(
int page) → int - Validates page number.
-
validateSearchText(
String? text, {String field = 'value'}) → String - Validates search query text.
-
validateSharhId(
String? id) → String - Validates sharh ID format.
-
validateTimeout(
Duration? timeout) → Duration - Validates a timeout duration.
-
validateUrl(
String? url) → String - Validates a URL string.